===================
Statsd Daemon Usage
===================

What Is It?
===========
`Statsd`_ is a network daemon that listens for statistics sent over the network
using TCP or UDP and that send aggregates to another backend.

Gnocchi provides a daemon that is compatible with the statsd protocol and can
listen to metrics sent over the network, named `gnocchi-statsd`.

.. _`Statsd`: https://github.com/etsy/statsd/

How It Works?
=============
In order to enable statsd support in Gnocchi, you need to configure the
`[statsd]` option group in the configuration file. You need to provide a
resource id that will be used as a the main generic resource where all the
metrics will be attached, a user and project id that will be used to create the
resource and metrics for, and an archive policy name that will be used to
create the metrics.

All the metrics will be created dynamically as the metrics are sent to
`gnocchi-statsd`, and attached with the provided name to the resource id you
provided.


.. note ::
   The statsd protocol support is incomplete: relative gauges values with +/-
   and sets are not supported yet.
